pub struct GreedyQuadsBuffer {
pub quads: QuadBuffer,
/* private fields */
}Expand description
Contains the output from the greedy_quads algorithm. The quads can be used to generate a mesh. See the methods on
OrientedBlockFace and UnorientedQuad for details.
This buffer can be reused between multiple calls of greedy_quads in order to avoid reallocations.
Fields
quads: QuadBufferImplementations